@@ -2,8 +2,10 @@
 from ... import _util
 from .skill_grammar import SkillFile, SkillContext, SkillInterpreter, _skill_if
 
+
 __all__ = ["AssuraFile", "AssuraInterpreter"]
 
+
 #
 # Script interpretation support classes
 #
@@ -14,12 +16,14 @@ class LayerDef(dict):
             s = s[6:]
         return s
 
+
 class DRCExtractContext(SkillContext):
     def __init__(self, context):
         super().__init__(parent=context)
         self.rules = []
         self.extracts = {}
 
+
 class LayerOperation:
     binops = {
         "geomAnd": "&",
@@ -57,6 +61,7 @@ class LayerOperation:
             assert len(self.args) == 2
             return f"({repr(self.args[0])}{binop}{repr(self.args[1])})"
 
+
 class AssuraInterpreter(SkillInterpreter):
     def __init__(self):
         super().__init__()
@@ -190,6 +195,7 @@ def _switch(elems, **kwargs):
     elem = _util.strip_literal(elems[0])
     return elem
 
+
 def _layerDefs(elems, **kwargs):
     def parse_type(layerspecs, base, typespec):
         base = _util.strip_literal(base)
@@ -242,7 +248,7 @@ def _layerDefs(elems, **kwargs):
                                 assert len(layertype) == 1
                                 parse_type(layerspecs, base, _util.strip_literal(layertype["type"]))
                             else:
-                                raise ValueError("type dict expected as second element in {!r}".format(l))
+                                raise ValueError(f"type dict expected as second element in {l!r}")
                         else:
                             layerspecs.append(str(l))
                 if len(layerspecs) == 1:
@@ -251,6 +257,7 @@ def _layerDefs(elems, **kwargs):
 
     return {name: d}
 
+
 def _drcExtractRules(elems, *, top=True, unknownfuncs=set(), **kwars):
     _known_funcs = {
         "if", "when", "for", "foreach", "evalstring", "sprintf", "let", "prog", "lambda",
@@ -333,14 +340,13 @@ def _drcExtractRules(elems, *, top=True, unknownfuncs=set(), **kwars):
                             "body": subvalue["statements"],
                         }
                 elif key in ("if", "ivIf", "when"):
-                    d = dict(
-                        (
-                            key,
+                    d = {
+                            key:
                             statements if key == "cond" else _drcExtractRules(
                                 statements, top=False, unknownfuncs=unknownfuncs
                             )
-                        ) for key, statements in body.items()
-                    )
+                         for key, statements in body.items()
+                    }
                     assert "procedures" not in d["then"]
                     if "else" in d:
                         assert "procedures" not in d["else"]
@@ -370,11 +376,12 @@ def _drcExtractRules(elems, *, top=True, unknownfuncs=set(), **kwars):
     if top and len(unknownfuncs) > 0:
         print("Unknown functions in drcExtractRules:")
         for func in unknownfuncs:
-            print("\t{}".format(func))
+            print(f"\t{func}")
         raise(ValueError)
 
     return value
 
+
 def _extractDevice(elems, *, type_, **kwargs):
     value = {
         "name": _util.strip_literal(elems[0]),
@@ -402,6 +409,7 @@ def _extractDevice(elems, *, type_, **kwargs):
 
     return value
 
+
 _value4function_table = {
     "switch": _switch,
     "avSwitch": _switch,
@@ -417,6 +425,7 @@ _value4function_table = {
     #TODO: avCompareRules
 }
 
+
 #
 # Grammar
 #
@@ -428,7 +437,8 @@ class AssuraFile(SkillFile):
 
     @classmethod
     def parse_string(cls, text):
-        return super(AssuraFile, cls).parse_string(text, value4funcs=_value4function_table)
+        return super().parse_string(text, value4funcs=_value4function_table)
+
 
 class AssuraDRC(dict):
     @staticmethod
@@ -483,9 +493,9 @@ class AssuraDRC(dict):
         for key in keys:
             print("{}:".format("Unconditioned" if key == "" else key))
             for checktype, checks in self[key].items():
-                print("  {}:".format(checktype))
+                print(f"  {checktype}:")
                 for check in checks:
-                    print("    {}".format(check))
+                    print(f"    {check}")
 
     def get_sigs(self):
         sigs = {}
@@ -493,7 +503,7 @@ class AssuraDRC(dict):
             for checktype, checks in checktypes.items():
                 if checktype not in ("drc", "errorLayer", "offGrid"):
                     continue
-                checksigs = set(tuple(type(expr) for expr in check) for check in checks)
+                checksigs = {tuple(type(expr) for expr in check) for check in checks}
                 if checktype in sigs:
                     sigs[checktype].update(checksigs)
                 else:
