@@ -3,8 +3,10 @@ import abc
 
 from .. import _util
 
+
 __all__ = ["Rules"]
 
+
 class _Rule(abc.ABC):
     @abc.abstractmethod
     def __init__(self):
@@ -23,6 +25,8 @@ class _Rule(abc.ABC):
     def __hash__(self):
         raise TypeError("subclasses of _Rule need to implement __hash__()")
 
-class Rules(_util.TypedTuple):
-    tt_element_type = _Rule
-    tt_index_attribute = None
+
+class Rules(_util.TypedList[_Rule]):
+    @property
+    def _elem_type_(self):
+        return _Rule
