@@ -2,8 +2,10 @@
 from .. import _util
 from . import net as net_, mask as msk
 
+
 __all__ = ["wafer", "SubstrateNet"]
 
+
 class _Wafer(msk._Mask):
     generated = False
 
@@ -13,9 +15,9 @@ class _Wafer(msk._Mask):
             raise ValueError("Creating new '_Wafer' object is not allowed. One needs to use wafer.wafer")
         else:
             _Wafer.generated = True
-        super().__init__("wafer")
+        super().__init__(name="wafer")
 
-        self.grid = msk._MaskProperty(self, "grid")
+        self.grid = msk._MaskProperty(mask=self, name="grid")
 
     @property
     def designmasks(self):
@@ -23,6 +25,7 @@ class _Wafer(msk._Mask):
 
 wafer = _Wafer()
 
+
 def outside(masks, *, alias=None):
     masks = _util.v2t(masks)
     if len(masks) == 1:
